# swspy

A package for performing shear wave splitting in an automated manner. Based on the eigenvalue method of Silver and Chan (1991), with multi-windowing of Teanby et al (2004), coordinate system transformations from Walsh et al (2013), automation methods based on Wustefeld et al (2010), and some other additions.

## To cite:

If you find this package useful, please do consider citing it. The appropriate work to cite is a manuscript currently in review:
Hudson, T.S., Asplet, J., Walker, A.M.. (in review) "Automated shear-wave splitting analysis for single- and multi- layer anisotropic media". Seismica.


## Documentation:

Full documentation for the package is available [here](https://swspy.readthedocs.io/en/latest/).

## Examples:

Various example notebooks can be found in the examples directory, including the examples contained in the paper: Hudson et al. (in review), Seismica.